@@ -1,5 +1,4 @@
-centre <-
-function(x, type)
+centre <- function(x, type)
 {
 switch(type, mean = func.mean(t(x)), var = func.var(t(x)),
 median = depth.FM(t(x))$median,
