@@ -1,4 +1,4 @@
-depth.radius = function(data, alpha, beta, weight)
+depth.radius <- function(data, alpha, beta, weight)
 {
 	data = t(data$y)
 	p = dim(data)[2]
@@ -45,4 +45,4 @@ depth.radius = function(data, alpha, beta, weight)
 	
 	
 	
-	
\ No newline at end of file
+	
